@@ -291,8 +291,7 @@ int
 shishi_ap_set_tktoptionsraw (Shishi_ap * ap,
 			     Shishi_tkt * tkt,
 			     int options,
-			     int32_t cksumtype,
-			     const char *data, size_t len)
+			     int32_t cksumtype, const char *data, size_t len)
 {
   int rc;
 
@@ -339,7 +338,7 @@ shishi_ap_set_tktoptionsasn1usage (Shishi_ap * ap,
   size_t buflen;
   int res;
 
-  res = shishi_a2d_new_field (ap->handle, node, field, &buf, &buflen);
+  res = shishi_asn1_to_der_field (ap->handle, node, field, &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
@@ -445,8 +444,7 @@ int
 shishi_ap_tktoptionsraw (Shishi * handle,
 			 Shishi_ap ** ap,
 			 Shishi_tkt * tkt, int options,
-			 int32_t cksumtype,
-			 const char *data, size_t len)
+			 int32_t cksumtype, const char *data, size_t len)
 {
   int rc;
 
@@ -609,8 +607,8 @@ shishi_ap_authenticator_cksumdata_set (Shishi_ap * ap,
 				       const char *authenticatorcksumdata,
 				       size_t authenticatorcksumdatalen)
 {
-  ap->authenticatorcksumdata = xclone (authenticatorcksumdata,
-				       authenticatorcksumdatalen);
+  ap->authenticatorcksumdata = xmemdup (authenticatorcksumdata,
+					authenticatorcksumdatalen);
   ap->authenticatorcksumdatalen = authenticatorcksumdatalen;
 }
 
@@ -635,8 +633,8 @@ shishi_ap_authenticator_cksumraw_set (Shishi_ap * ap,
 				      size_t authenticatorcksumrawlen)
 {
   shishi_ap_authenticator_cksumtype_set (ap, authenticatorcksumtype);
-  ap->authenticatorcksumraw = xclone (authenticatorcksumraw,
-				      authenticatorcksumrawlen);
+  ap->authenticatorcksumraw = xmemdup (authenticatorcksumraw,
+				       authenticatorcksumrawlen);
   ap->authenticatorcksumrawlen = authenticatorcksumrawlen;
 }
 
@@ -746,7 +744,7 @@ shishi_ap_req_der (Shishi_ap * ap, char **out, size_t * outlen)
   if (rc != SHISHI_OK)
     return rc;
 
-  rc = shishi_new_a2d (ap->handle, ap->apreq, out, outlen);
+  rc = shishi_asn1_to_der (ap->handle, ap->apreq, out, outlen);
   if (rc != SHISHI_OK)
     return rc;
 
@@ -1093,7 +1091,7 @@ shishi_ap_rep_der (Shishi_ap * ap, char **out, size_t * outlen)
   if (rc != SHISHI_OK)
     return rc;
 
-  rc = shishi_new_a2d (ap->handle, ap->aprep, out, outlen);
+  rc = shishi_asn1_to_der (ap->handle, ap->aprep, out, outlen);
   if (rc != SHISHI_OK)
     return rc;
 
@@ -1145,7 +1143,8 @@ shishi_ap_rep_build (Shishi_ap * ap)
     printf ("Building AP-REP...\n");
 
   aprep = shishi_aprep (ap->handle);
-  rc = shishi_aprep_enc_part_make (ap->handle, aprep, ap->authenticator,
+  rc = shishi_aprep_enc_part_make (ap->handle, aprep, ap->encapreppart,
+				   ap->authenticator,
 				   shishi_tkt_encticketpart (ap->tkt));
   if (rc != SHISHI_OK)
     {
