@@ -81,7 +81,7 @@ shishi_authenticator (Shishi * handle)
    * it and the successive sequence numbers do not repeat other
    * sequences.
    */
-  shishi_randomize (handle, 0, &seqnr, sizeof(seqnr));
+  shishi_randomize (handle, 0, &seqnr, sizeof (seqnr));
 
   /* XXX remove once libtasn1 _asn1_convert_integer is fixed. */
   seqnr &= 0x7FFFFFFF;
@@ -389,8 +389,7 @@ shishi_authenticator_client_set (Shishi * handle,
  **/
 int
 shishi_authenticator_ctime (Shishi * handle,
-			    Shishi_asn1 authenticator,
-			    char **t)
+			    Shishi_asn1 authenticator, char **t)
 {
   return shishi_time (handle, authenticator, "ctime", t);
 }
@@ -407,13 +406,12 @@ shishi_authenticator_ctime (Shishi * handle,
  **/
 int
 shishi_authenticator_ctime_set (Shishi * handle,
-				Shishi_asn1 authenticator,
-				const char *t)
+				Shishi_asn1 authenticator, const char *t)
 {
   int res;
 
   res = shishi_asn1_write (handle, authenticator, "ctime",
-			   t, GENERALIZEDTIME_TIME_LEN);
+			   t, SHISHI_GENERALIZEDTIME_LENGTH);
   if (res != SHISHI_OK)
     return res;
 
@@ -432,8 +430,7 @@ shishi_authenticator_ctime_set (Shishi * handle,
  **/
 int
 shishi_authenticator_cusec_get (Shishi * handle,
-				Shishi_asn1 authenticator,
-				uint32_t *cusec)
+				Shishi_asn1 authenticator, uint32_t * cusec)
 {
   int res;
 
@@ -456,8 +453,7 @@ shishi_authenticator_cusec_get (Shishi * handle,
  **/
 int
 shishi_authenticator_cusec_set (Shishi * handle,
-				Shishi_asn1 authenticator,
-				uint32_t cusec)
+				Shishi_asn1 authenticator, uint32_t cusec)
 {
   int res;
 
@@ -540,25 +536,57 @@ shishi_authenticator_seqnumber_set (Shishi * handle,
   return SHISHI_OK;
 }
 
+/**
+ * shishi_authenticator_client:
+ * @handle: Shishi library handle create by shishi_init().
+ * @authenticator: Authenticator variable to get client name from.
+ * @client: pointer to newly allocated zero terminated string containing
+ *   principal name.  May be %NULL (to only populate @clientlen).
+ * @clientlen: pointer to length of @client on output, excluding terminating
+ *   zero.  May be %NULL (to only populate @client).
+ *
+ * Represent client principal name in Authenticator as zero-terminated
+ * string.  The string is allocate by this function, and it is the
+ * responsibility of the caller to deallocate it.  Note that the
+ * output length @clientlen does not include the terminating zero.
+ *
+ * Return value: Returns SHISHI_OK iff successful.
+ **/
 int
-shishi_authenticator_cname_get (Shishi * handle,
-				Shishi_asn1 authenticator,
-				char *cname, size_t * cnamelen)
+shishi_authenticator_client (Shishi * handle,
+			     Shishi_asn1 authenticator,
+			     char **client, size_t * clientlen)
 {
-  return shishi_principal_name_get (handle, authenticator,
-				    "cname", cname, cnamelen);
+  return shishi_principal_name (handle, authenticator,
+				"cname", client, clientlen);
 }
 
+/**
+ * shishi_authenticator_clientrealm:
+ * @handle: Shishi library handle create by shishi_init().
+ * @authenticator: Authenticator variable to get client name and realm from.
+ * @client: pointer to newly allocated zero terminated string containing
+ *   principal name and realm.  May be %NULL (to only populate @clientlen).
+ * @clientlen: pointer to length of @client on output, excluding terminating
+ *   zero.  May be %NULL (to only populate @client).
+ *
+ * Convert cname and realm fields from Authenticator to printable
+ * principal name format.  The string is allocate by this function,
+ * and it is the responsibility of the caller to deallocate it.  Note
+ * that the output length @clientlen does not include the terminating
+ * zero.
+ *
+ * Return value: Returns SHISHI_OK iff successful.
+ **/
 int
-shishi_authenticator_cnamerealm_get (Shishi * handle,
-				     Shishi_asn1 authenticator,
-				     char *cnamerealm, size_t * cnamerealmlen)
+shishi_authenticator_clientrealm (Shishi * handle,
+				  Shishi_asn1 authenticator,
+				  char **client, size_t * clientlen)
 {
-  return shishi_principal_name_realm_get (handle, authenticator,
-					  "cname",
-					  authenticator,
-					  "crealm",
-					  cnamerealm, cnamerealmlen);
+  return shishi_principal_name_realm (handle,
+				      authenticator, "cname",
+				      authenticator, "crealm",
+				      client, clientlen);
 }
 
 int
@@ -602,8 +630,8 @@ shishi_authenticator_cksum (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
-  res = shishi_asn1_read2 (handle, authenticator, "cksum.checksum",
-			   cksum, cksumlen);
+  res = shishi_asn1_read (handle, authenticator, "cksum.checksum",
+			  cksum, cksumlen);
   if (res != SHISHI_OK)
     return res;
 
@@ -794,9 +822,8 @@ shishi_authenticator_add_authorizationdata (Shishi * handle,
  * @handle: shishi handle as allocated by shishi_init().
  * @authenticator: authenticator as allocated by shishi_authenticator().
  * @adtype: output authorization data type.
- * @addata: output authorization data.
- * @addatalen: on input, maximum size of output authorization data,
- *             on output, actual size of authorization data.
+ * @addata: newly allocated output authorization data.
+ * @addatalen: on output, actual size of newly allocated authorization data.
  * @nth: element number of authorization-data to extract.
  *
  * Extract n:th authorization data from authenticator.  The first
@@ -807,8 +834,8 @@ shishi_authenticator_add_authorizationdata (Shishi * handle,
 int
 shishi_authenticator_authorizationdata (Shishi * handle,
 					Shishi_asn1 authenticator,
-					int32_t *adtype,
-					char *addata, size_t * addatalen,
+					int32_t * adtype,
+					char **addata, size_t * addatalen,
 					size_t nth)
 {
   char *format;
@@ -886,8 +913,8 @@ shishi_authenticator_get_subkey (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
-  res = shishi_asn1_read2 (handle, authenticator, "subkey.keyvalue",
-			   &subkeyvalue, &subkeylen);
+  res = shishi_asn1_read (handle, authenticator, "subkey.keyvalue",
+			  &subkeyvalue, &subkeylen);
   if (res != SHISHI_OK)
     return res;
 
