@@ -70,7 +70,7 @@ shishi_encapreppart (Shishi * handle)
    * it and the successive sequence numbers do not repeat other
    * sequences.
    */
-  shishi_randomize (handle, 0, &seqnr, sizeof(seqnr));
+  shishi_randomize (handle, 0, &seqnr, sizeof (seqnr));
 
   /*
    * Implementation note: as noted before, some implementations omit
@@ -262,10 +262,7 @@ shishi_encapreppart_from_file (Shishi * handle, Shishi_asn1 * encapreppart,
  * shishi_encapreppart_get_key:
  * @handle: shishi handle as allocated by shishi_init().
  * @encapreppart: input EncAPRepPart variable.
- * @keytype: output variable that holds key type.
- * @keyvalue: output array with key.
- * @keyvalue_len: on input, maximum size of output array with key,
- *                on output, holds the actual size of output array with key.
+ * @key: newly allocated key.
  *
  * Extract the subkey from the encrypted AP-REP part.
  *
@@ -273,20 +270,28 @@ shishi_encapreppart_from_file (Shishi * handle, Shishi_asn1 * encapreppart,
  **/
 int
 shishi_encapreppart_get_key (Shishi * handle,
-			     Shishi_asn1 encapreppart,
-			     int32_t * keytype,
-			     char *keyvalue, size_t * keyvalue_len)
+			     Shishi_asn1 encapreppart, Shishi_key ** key)
 {
   int res;
+  char *buf;
+  size_t buflen;
+  int32_t keytype;
 
-  *keytype = 0;
   res = shishi_asn1_read_int32 (handle, encapreppart,
-				"subkey.keytype", keytype);
+				"subkey.keytype", &keytype);
   if (res != SHISHI_OK)
     return res;
 
-  res = shishi_asn1_read (handle, encapreppart,
-			  "subkey.keyvalue", keyvalue, keyvalue_len);
+  res = shishi_asn1_read (handle, encapreppart, "subkey.keyvalue",
+			  &buf, &buflen);
+  if (res != SHISHI_OK)
+    return res;
+
+  if (shishi_cipher_keylen (keytype) != buflen)
+    return SHISHI_ENCAPREPPART_BAD_KEYTYPE;
+
+  res = shishi_key_from_value (handle, keytype, buf, key);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
@@ -305,8 +310,7 @@ shishi_encapreppart_get_key (Shishi * handle,
  **/
 int
 shishi_encapreppart_ctime (Shishi * handle,
-			   Shishi_asn1 encapreppart,
-			   char **t)
+			   Shishi_asn1 encapreppart, char **t)
 {
   return shishi_time (handle, encapreppart, "ctime", t);
 }
@@ -323,13 +327,12 @@ shishi_encapreppart_ctime (Shishi * handle,
  **/
 int
 shishi_encapreppart_ctime_set (Shishi * handle,
-			       Shishi_asn1 encapreppart,
-			       const char *t)
+			       Shishi_asn1 encapreppart, const char *t)
 {
   int res;
 
   res = shishi_asn1_write (handle, encapreppart, "ctime",
-			   t, GENERALIZEDTIME_TIME_LEN);
+			   t, SHISHI_GENERALIZEDTIME_LENGTH);
   if (res != SHISHI_OK)
     return res;
 
@@ -348,8 +351,7 @@ shishi_encapreppart_ctime_set (Shishi * handle,
  **/
 int
 shishi_encapreppart_cusec_get (Shishi * handle,
-			       Shishi_asn1 encapreppart,
-			       uint32_t *cusec)
+			       Shishi_asn1 encapreppart, uint32_t * cusec)
 {
   int res;
 
@@ -372,8 +374,7 @@ shishi_encapreppart_cusec_get (Shishi * handle,
  **/
 int
 shishi_encapreppart_cusec_set (Shishi * handle,
-			       Shishi_asn1 encapreppart,
-			       uint32_t cusec)
+			       Shishi_asn1 encapreppart, uint32_t cusec)
 {
   int res;
 
@@ -475,7 +476,7 @@ shishi_encapreppart_time_copy (Shishi * handle,
   size_t buflen;
   int res;
 
-  res = shishi_asn1_read2 (handle, authenticator, "cusec", &buf, &buflen);
+  res = shishi_asn1_read (handle, authenticator, "cusec", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
@@ -484,7 +485,7 @@ shishi_encapreppart_time_copy (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
-  res = shishi_asn1_read2 (handle, authenticator, "ctime", &buf, &buflen);
+  res = shishi_asn1_read (handle, authenticator, "ctime", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
