@@ -24,7 +24,7 @@
 struct shishi_error_msgs
 {
   int errorcode;
-  char *message;
+  const char *message;
 };
 
 struct shishi_error_msgs _shishi_error_messages[] = {
