@@ -134,7 +134,6 @@
 #define gettext_noop(String) String
 #define N_(String) gettext_noop (String)
 
-#define GENERALIZEDTIME_TIME_LEN 15
 #define MAX_KEY_LEN 32
 #define MAX_RANDOM_LEN 32
 #define MAX_HASH_LEN 32
@@ -158,6 +157,11 @@
 		  SHISHI_VERBOSE_CRYPTO_NOISE)
 #define VERBOSE(h) (h->verbose & ~VERBOSES)
 
+/* For resolv.c and netio.c, on old systems. */
+#ifndef T_SRV
+# define T_SRV (33)
+#endif
+
 enum
 {
   UDP,
