@@ -109,7 +109,7 @@ _shishi_kdcreq (Shishi * handle, int as)
     goto error;
 
   shishi_randomize (handle, 0, &nonce, sizeof (nonce));
-  nonce &= 0x7FFFFFFF; /* XXX fix _libtasn1_convert_integer. */
+  nonce &= 0x7FFFFFFF;		/* XXX fix _libtasn1_convert_integer. */
   res = shishi_kdcreq_nonce_set (handle, node, nonce);
   if (res != SHISHI_OK)
     goto error;
@@ -353,9 +353,7 @@ shishi_kdcreq_nonce (Shishi * handle, Shishi_asn1 kdcreq, uint32_t * nonce)
  * Return value: Returns %SHISHI_OK iff successful.
  **/
 int
-shishi_kdcreq_nonce_set (Shishi * handle,
-			 Shishi_asn1 kdcreq,
-			 uint32_t nonce)
+shishi_kdcreq_nonce_set (Shishi * handle, Shishi_asn1 kdcreq, uint32_t nonce)
 {
   int res;
 
@@ -416,23 +414,31 @@ shishi_kdcreq_client (Shishi * handle, Shishi_asn1 kdcreq,
 				client, clientlen);
 }
 
+/**
+ * shishi_asreq_clientrealm:
+ * @handle: Shishi library handle create by shishi_init().
+ * @asreq: AS-REQ variable to get client name and realm from.
+ * @client: pointer to newly allocated zero terminated string containing
+ *   principal name and realm.  May be %NULL (to only populate @clientlen).
+ * @clientlen: pointer to length of @client on output, excluding terminating
+ *   zero.  May be %NULL (to only populate @client).
+ *
+ * Convert cname and realm fields from AS-REQ to printable principal
+ * name format.  The string is allocate by this function, and it is
+ * the responsibility of the caller to deallocate it.  Note that the
+ * output length @clientlen does not include the terminating zero.
+ *
+ * Return value: Returns SHISHI_OK iff successful.
+ **/
 int
-shishi_kdcreq_cname_get (Shishi * handle,
-			 Shishi_asn1 kdcreq, char *cname, size_t * cnamelen)
+shishi_asreq_clientrealm (Shishi * handle,
+			  Shishi_asn1 asreq,
+			  char **client, size_t * clientlen)
 {
-  return shishi_principal_name_get (handle, kdcreq,
-				    "req-body.cname", cname, cnamelen);
-}
-
-int
-shishi_asreq_cnamerealm_get (Shishi * handle,
-			     Shishi_asn1 asreq,
-			     char *cnamerealm, size_t * cnamerealmlen)
-{
-  return shishi_principal_name_realm_get (handle, asreq,
-					  "req-body.cname", asreq,
-					  "req-body.realm",
-					  cnamerealm, cnamerealmlen);
+  return shishi_principal_name_realm (handle,
+				      asreq, "req-body.cname",
+				      asreq, "req-body.realm",
+				      client, clientlen);
 }
 
 /**
@@ -455,13 +461,13 @@ int
 shishi_kdcreq_realm (Shishi * handle, Shishi_asn1 kdcreq,
 		     char **realm, size_t * realmlen)
 {
-  return shishi_asn1_read2_optional (handle, kdcreq, "req-body.realm",
-				     realm, realmlen);
+  return shishi_asn1_read_optional (handle, kdcreq, "req-body.realm",
+				    realm, realmlen);
 }
 
 int
 shishi_kdcreq_realm_get (Shishi * handle, Shishi_asn1 kdcreq,
-			 char *realm, size_t * realmlen)
+			 char **realm, size_t * realmlen)
 {
   return shishi_asn1_read_optional (handle, kdcreq, "req-body.realm",
 				    realm, realmlen);
@@ -514,25 +520,6 @@ shishi_kdcreq_server (Shishi * handle, Shishi_asn1 kdcreq,
 				server, serverlen);
 }
 
-int
-shishi_kdcreq_sname_get (Shishi * handle,
-			 Shishi_asn1 kdcreq, char *sname, size_t * snamelen)
-{
-  return shishi_principal_name_get (handle, kdcreq,
-				    "req-body.sname", sname, snamelen);
-}
-
-int
-shishi_kdcreq_snamerealm_get (Shishi * handle,
-			      Shishi_asn1 kdcreq,
-			      char *snamerealm, size_t * snamerealmlen)
-{
-  return shishi_principal_name_realm_get (handle, kdcreq,
-					  "req-body.sname", kdcreq,
-					  "req-body.realm",
-					  snamerealm, snamerealmlen);
-}
-
 /**
  * shishi_kdcreq_set_sname:
  * @handle: shishi handle as allocated by shishi_init().
@@ -612,14 +599,13 @@ int
 shishi_kdcreq_till (Shishi * handle, Shishi_asn1 kdcreq,
 		    char **till, size_t * tilllen)
 {
-  return shishi_asn1_read2 (handle, kdcreq, "req-body.till",
-			    till, tilllen);
+  return shishi_asn1_read (handle, kdcreq, "req-body.till", till, tilllen);
 }
 
 /**
  * shishi_kdcreq_tillc:
  * @handle: Shishi library handle create by shishi_init().
- * @tkt: input variable with ticket info.
+ * @kdcreq: KDC-REQ variable to get till field from.
  *
  * Extract C time corresponding to the "till" field.
  *
@@ -631,14 +617,14 @@ shishi_kdcreq_tillc (Shishi * handle, Shishi_asn1 kdcreq)
 {
   char *till;
   size_t tilllen;
-  time_t t = (time_t) -1;
+  time_t t = (time_t) - 1;
   int res;
 
   res = shishi_kdcreq_till (handle, kdcreq, &till, &tilllen);
   if (res != SHISHI_OK)
     return t;
 
-  if (tilllen == GENERALIZEDTIME_TIME_LEN + 1) /* XXX why +1 ? */
+  if (tilllen == SHISHI_GENERALIZEDTIME_LENGTH + 1)	/* XXX why +1 ? */
     t = shishi_generalize_ctime (handle, till);
 
   free (till);
@@ -1166,7 +1152,7 @@ shishi_kdcreq_get_padata (Shishi * handle,
       if (patype == (int32_t) padatatype)
 	{
 	  asprintf (&format, "padata.?%d.padata-value", i);
-	  res = shishi_asn1_read2 (handle, kdcreq, format, out, outlen);
+	  res = shishi_asn1_read (handle, kdcreq, format, out, outlen);
 	  free (format);
 	  if (res != SHISHI_OK)
 	    return res;
@@ -1285,7 +1271,7 @@ shishi_kdcreq_add_padata_tgs (Shishi * handle,
   char *data;
   size_t datalen;
 
-  res = shishi_new_a2d (handle, apreq, &data, &datalen);
+  res = shishi_asn1_to_der (handle, apreq, &data, &datalen);
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle, "Could not DER encode AP-REQ: %s\n",
