@@ -298,11 +298,12 @@ shishi_krberror_build (Shishi * handle, Shishi_asn1 krberror)
 	return rc;
     }
 
-  tmplen = sizeof (t);
-  rc = shishi_krberror_cname (handle, krberror, t, &tmplen);
+  rc = shishi_krberror_client (handle, krberror, &tmp, &tmplen);
   if (rc != SHISHI_OK &&
       rc != SHISHI_ASN1_NO_ELEMENT && rc != SHISHI_ASN1_NO_VALUE)
     return rc;
+  if (rc == SHISHI_OK)
+    free (tmp);
   if (rc == SHISHI_ASN1_NO_VALUE || (rc == SHISHI_OK && tmplen == 0))
     {
       rc = shishi_krberror_remove_cname (handle, krberror);
@@ -322,10 +323,11 @@ shishi_krberror_build (Shishi * handle, Shishi_asn1 krberror)
 	return rc;
     }
 
-  tmplen = sizeof (t);
-  rc = shishi_krberror_sname (handle, krberror, t, &tmplen);
+  rc = shishi_krberror_server (handle, krberror, &tmp, &tmplen);
   if (rc != SHISHI_OK && rc != SHISHI_ASN1_NO_VALUE)
     return rc;
+  if (rc == SHISHI_OK)
+    free (tmp);
   if (rc == SHISHI_ASN1_NO_VALUE || tmplen == 0)
     {
       rc = shishi_krberror_remove_sname (handle, krberror);
@@ -399,7 +401,7 @@ shishi_krberror_der (Shishi * handle,
   if (rc != SHISHI_OK)
     return rc;
 
-  rc = shishi_new_a2d (handle, krberror, out, outlen);
+  rc = shishi_asn1_to_der (handle, krberror, out, outlen);
   if (rc != SHISHI_OK)
     return rc;
 
@@ -421,7 +423,7 @@ int
 shishi_krberror_crealm (Shishi * handle,
 			Shishi_asn1 krberror, char **realm, size_t * realmlen)
 {
-  return shishi_asn1_read2 (handle, krberror, "crealm", realm, realmlen);
+  return shishi_asn1_read (handle, krberror, "crealm", realm, realmlen);
 }
 
 /**
@@ -469,24 +471,26 @@ shishi_krberror_set_crealm (Shishi * handle,
 }
 
 /**
- * shishi_krberror_cname:
+ * shishi_krberror_client:
  * @handle: shishi handle as allocated by shishi_init().
  * @krberror: krberror as allocated by shishi_krberror().
- * @out: output buffer that holds client name in KRB-ERROR.
- * @outlen: on input, maximum size of output buffer,
- *             on output, actual size of output buffer.
+ * @client: pointer to newly allocated zero terminated string containing
+ *   principal name.  May be %NULL (to only populate @clientlen).
+ * @clientlen: pointer to length of @client on output, excluding terminating
+ *   zero.  May be %NULL (to only populate @client).
  *
- * Return client principal field in KRB-ERROR.
+ * Return client principal name in KRB-ERROR.
  *
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_krberror_cname (Shishi * handle,
-		       Shishi_asn1 krberror, char *out, size_t * outlen)
+shishi_krberror_client (Shishi * handle,
+			Shishi_asn1 krberror,
+			char **client, size_t * clientlen)
 {
   int rc;
 
-  rc = shishi_principal_name_get (handle, krberror, "cname", out, outlen);
+  rc = shishi_principal_name (handle, krberror, "cname", client, clientlen);
   if (rc != SHISHI_OK)
     return rc;
 
@@ -579,7 +583,7 @@ int
 shishi_krberror_realm (Shishi * handle,
 		       Shishi_asn1 krberror, char **realm, size_t * realmlen)
 {
-  return shishi_asn1_read2 (handle, krberror, "realm", realm, realmlen);
+  return shishi_asn1_read (handle, krberror, "realm", realm, realmlen);
 }
 
 /**
@@ -606,24 +610,26 @@ shishi_krberror_set_realm (Shishi * handle,
 }
 
 /**
- * shishi_krberror_sname:
+ * shishi_krberror_server:
  * @handle: shishi handle as allocated by shishi_init().
  * @krberror: krberror as allocated by shishi_krberror().
- * @out: output buffer that holds server name in KRB-ERROR.
- * @outlen: on input, maximum size of output buffer,
- *             on output, actual size of output buffer.
+ * @server: pointer to newly allocated zero terminated string containing
+ *   server name.  May be %NULL (to only populate @serverlen).
+ * @snamelen: pointer to length of @server on output, excluding terminating
+ *   zero.  May be %NULL (to only populate @server).
  *
- * Return server principal field in KRB-ERROR.
+ * Return server principal name in KRB-ERROR.
  *
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_krberror_sname (Shishi * handle,
-		       Shishi_asn1 krberror, char *out, size_t * outlen)
+shishi_krberror_server (Shishi * handle,
+			Shishi_asn1 krberror,
+			char **server, size_t * serverlen)
 {
   int rc;
 
-  rc = shishi_principal_name_get (handle, krberror, "sname", out, outlen);
+  rc = shishi_principal_name (handle, krberror, "sname", server, serverlen);
   if (rc != SHISHI_OK)
     return rc;
 
@@ -736,14 +742,13 @@ shishi_krberror_ctime (Shishi * handle, Shishi_asn1 krberror, char **t)
  **/
 int
 shishi_krberror_ctime_set (Shishi * handle,
-			   Shishi_asn1 krberror,
-			   const char *t)
+			   Shishi_asn1 krberror, const char *t)
 {
   int res;
 
   if (t)
     res = shishi_asn1_write (handle, krberror, "ctime",
-			     t, GENERALIZEDTIME_TIME_LEN);
+			     t, SHISHI_GENERALIZEDTIME_LENGTH);
   else
     res = shishi_asn1_write (handle, krberror, "ctime", NULL, 0);
   if (res != SHISHI_OK)
@@ -784,7 +789,8 @@ shishi_krberror_remove_ctime (Shishi * handle, Shishi_asn1 krberror)
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_krberror_cusec (Shishi * handle, Shishi_asn1 krberror, uint32_t *cusec)
+shishi_krberror_cusec (Shishi * handle, Shishi_asn1 krberror,
+		       uint32_t * cusec)
 {
   int res;
 
@@ -807,8 +813,7 @@ shishi_krberror_cusec (Shishi * handle, Shishi_asn1 krberror, uint32_t *cusec)
  **/
 int
 shishi_krberror_cusec_set (Shishi * handle,
-			   Shishi_asn1 krberror,
-			   uint32_t cusec)
+			   Shishi_asn1 krberror, uint32_t cusec)
 {
   int res;
 
@@ -873,7 +878,7 @@ shishi_krberror_stime_set (Shishi * handle,
   int res;
 
   res = shishi_asn1_write (handle, krberror, "stime",
-			   t, GENERALIZEDTIME_TIME_LEN);
+			   t, SHISHI_GENERALIZEDTIME_LENGTH);
   if (res != SHISHI_OK)
     return res;
 
@@ -892,8 +897,7 @@ shishi_krberror_stime_set (Shishi * handle,
  **/
 int
 shishi_krberror_susec (Shishi * handle,
-		       Shishi_asn1 krberror,
-		       uint32_t *susec)
+		       Shishi_asn1 krberror, uint32_t * susec)
 {
   int res;
 
@@ -916,8 +920,7 @@ shishi_krberror_susec (Shishi * handle,
  **/
 int
 shishi_krberror_susec_set (Shishi * handle,
-			   Shishi_asn1 krberror,
-			   uint32_t susec)
+			   Shishi_asn1 krberror, uint32_t susec)
 {
   int res;
 
@@ -1002,7 +1005,7 @@ int
 shishi_krberror_etext (Shishi * handle, Shishi_asn1 krberror,
 		       char **etext, size_t * etextlen)
 {
-  return shishi_asn1_read2 (handle, krberror, "e-text", etext, etextlen);
+  return shishi_asn1_read (handle, krberror, "e-text", etext, etextlen);
 }
 
 /**
@@ -1064,7 +1067,7 @@ int
 shishi_krberror_edata (Shishi * handle, Shishi_asn1 krberror,
 		       char **edata, size_t * edatalen)
 {
-  return shishi_asn1_read2 (handle, krberror, "e-data", edata, edatalen);
+  return shishi_asn1_read (handle, krberror, "e-data", edata, edatalen);
 }
 
 /**
@@ -1152,8 +1155,7 @@ shishi_krberror_pretty_print (Shishi * handle, FILE * fh,
       if (res == SHISHI_OK && len > 0)
 	{
 	  buf[len] = '\0';
-	  fprintf (fh, "Additional error message from server:\n%s\n",
-		   buf);
+	  fprintf (fh, "Additional error message from server:\n%s\n", buf);
 	}
     }
 
