@@ -202,7 +202,7 @@ shishi_priv_priv_der (Shishi_priv * priv, char **out, size_t * outlen)
 {
   int rc;
 
-  rc = shishi_new_a2d (priv->handle, priv->priv, out, outlen);
+  rc = shishi_asn1_to_der (priv->handle, priv->priv, out, outlen);
   if (rc != SHISHI_OK)
     return rc;
 
@@ -281,7 +281,7 @@ shishi_priv_encprivpart_der (Shishi_priv * priv, char **out, size_t * outlen)
 {
   int rc;
 
-  rc = shishi_new_a2d (priv->handle, priv->encprivpart, out, outlen);
+  rc = shishi_asn1_to_der (priv->handle, priv->encprivpart, out, outlen);
   if (rc != SHISHI_OK)
     return rc;
 
@@ -546,8 +546,8 @@ shishi_encprivpart_user_data (Shishi * handle,
 {
   int res;
 
-  res = shishi_asn1_read2 (handle, encprivpart, "user-data",
-			   userdata, userdatalen);
+  res = shishi_asn1_read (handle, encprivpart, "user-data",
+			  userdata, userdatalen);
   if (res != SHISHI_OK)
     return res;
 
@@ -600,7 +600,7 @@ shishi_priv_build (Shishi_priv * priv, Shishi_key * key)
   char *der;
   size_t derlen;
 
-  res = shishi_new_a2d (priv->handle, priv->encprivpart, &der, &derlen);
+  res = shishi_asn1_to_der (priv->handle, priv->encprivpart, &der, &derlen);
   if (res != SHISHI_OK)
     {
       shishi_error_printf (priv->handle,
@@ -658,8 +658,8 @@ shishi_priv_process (Shishi_priv * priv, Shishi_key * key)
   if (etype != shishi_key_type (key))
     return SHISHI_PRIV_BAD_KEYTYPE;
 
-  res = shishi_asn1_read2 (priv->handle, priv->priv, "enc-part.cipher",
-			   &cipher, &cipherlen);
+  res = shishi_asn1_read (priv->handle, priv->priv, "enc-part.cipher",
+			  &cipher, &cipherlen);
   if (res != SHISHI_OK)
     return res;
 
