@@ -27,7 +27,7 @@
 #include <time.h>		/* time_t */
 #include <shishi-int.h>		/* uint32_t */
 
-#define SHISHI_VERSION "0.0.17"
+#define SHISHI_VERSION "0.0.18"
 
 /* Error codes */
 typedef enum
@@ -82,7 +82,8 @@ typedef enum
   SHISHI_VERIFY_FAILED = 47,
   SHISHI_PRIV_BAD_KEYTYPE = 48,
   SHISHI_FILE_ERROR = 49,
-  SHISHI_LAST_ERROR = 49
+  SHISHI_ENCAPREPPART_BAD_KEYTYPE = 50,
+  SHISHI_LAST_ERROR = 50
 }
 Shishi_rc;
 
@@ -379,10 +380,8 @@ typedef enum
   SHISHI_KEYUSAGE_ACCEPTOR_SIGN = 23,
   SHISHI_KEYUSAGE_INITIATOR_SEAL = 24,
   SHISHI_KEYUSAGE_INITIATOR_SIGN = 25,
-  /* 16-18,20-21,25-511. Reserved for future use in Kerberos and related
-     protocols. */
-  /* 512-1023.      Reserved for uses internal to a Kerberos
-     implementation. */
+  /* 16-18,20-21,25-511. Reserved for future use. */
+  /* 512-1023.  Reserved for uses internal implementations. */
   /* 1024.         Encryption for application use in protocols that
      do not specify key usage values */
   /* 1025.         Checksums for application use in protocols that
@@ -411,9 +410,9 @@ typedef enum
   SHISHI_KDC_ERR_C_OLD_MAST_KVNO = 4,
   /* Server's key encrypted in old master key */
   SHISHI_KDC_ERR_S_OLD_MAST_KVNO = 5,
-  /* Client not found in Kerberos database */
+  /* Client not found in database */
   SHISHI_KDC_ERR_C_PRINCIPAL_UNKNOWN = 6,
-  /* Server not found in Kerberos database */
+  /* Server not found in database */
   SHISHI_KDC_ERR_S_PRINCIPAL_UNKNOWN = 7,
   /* Multiple principal entries in database */
   SHISHI_KDC_ERR_PRINCIPAL_NOT_UNIQUE = 8,
@@ -563,6 +562,32 @@ struct Shishi_tkts_hint
 };
 typedef struct Shishi_tkts_hint Shishi_tkts_hint;
 
+/* resolv.c */
+#define SHISHI_DNS_TXT 16
+#define SHISHI_DNS_SRV 33
+
+struct Shishi_dns_st
+{
+  struct Shishi_dns_st *next;
+
+  uint16_t class;
+  uint16_t type;
+  uint32_t ttl;
+
+  void *rr;
+};
+typedef struct Shishi_dns_st *Shishi_dns;
+
+struct Shishi_dns_srv_st
+{
+  uint16_t priority;
+  uint16_t weight;
+  uint16_t port;
+
+  char name[256];
+};
+typedef struct Shishi_dns_srv_st *Shishi_dns_srv;
+
 typedef struct Shishi Shishi;
 typedef struct Shishi_tkt Shishi_tkt;
 typedef struct Shishi_tkts Shishi_tkts;
@@ -578,6 +603,12 @@ typedef struct node_asn_struct *ASN1_TYPE;
 typedef ASN1_TYPE Shishi_asn1;
 typedef struct Shishi_crypto Shishi_crypto;
 
+#define SHISHI_GENERALIZEDTIME_LENGTH 15
+#define SHISHI_GENERALIZEDTIMEZ_LENGTH (SHISHI_GENERALIZEDTIME_LENGTH + 1)
+
+/* If non-NULL, call this function when memory is exhausted. */
+extern void (*shishi_alloc_fail_function) (void);
+
 /* init.c */
 extern Shishi *shishi (void);
 extern Shishi *shishi_server (void);
@@ -633,15 +664,12 @@ extern int shishi_principal_name (Shishi * handle,
 				  Shishi_asn1 namenode,
 				  const char *namefield,
 				  char **out, size_t * outlen);
-extern int shishi_principal_name_get (Shishi * handle, Shishi_asn1 namenode,
-				      const char *namefield, char *out,
-				      size_t * outlen);
-extern int shishi_principal_name_realm_get (Shishi * handle,
-					    Shishi_asn1 namenode,
-					    const char *namefield,
-					    Shishi_asn1 realmnode,
-					    const char *realmfield,
-					    char *out, size_t * outlen);
+extern int shishi_principal_name_realm (Shishi * handle,
+					Shishi_asn1 namenode,
+					const char *namefield,
+					Shishi_asn1 realmnode,
+					const char *realmfield,
+					char **out, size_t * outlen);
 extern int shishi_principal_name_set (Shishi * handle,
 				      Shishi_asn1 namenode,
 				      const char *namefield,
@@ -659,19 +687,14 @@ extern char *shishi_server_for_local_service (Shishi * handle,
 extern Shishi_asn1 shishi_ticket (Shishi * handle);
 extern int shishi_ticket_server (Shishi * handle, Shishi_asn1 ticket,
 				 char **server, size_t * serverlen);
-extern int shishi_ticket_sname_get (Shishi * handle,
-				    Shishi_asn1 ticket,
-				    char *server, size_t * serverlen);
 extern int shishi_ticket_sname_set (Shishi * handle,
 				    Shishi_asn1 ticket,
 				    Shishi_name_type name_type,
 				    char *sname[]);
-extern int shishi_ticket_snamerealm_get (Shishi * handle, Shishi_asn1 ticket,
-					 char *serverrealm,
-					 size_t * serverrealmlen);
 extern int shishi_ticket_srealmserver_set (Shishi * handle,
-					   Shishi_asn1 ticket, char *realm,
-					   char *server);
+					   Shishi_asn1 ticket,
+					   const char *realm,
+					   const char *server);
 extern int shishi_ticket_set_server (Shishi * handle, Shishi_asn1 ticket,
 				     const char *server);
 extern int shishi_ticket_realm_get (Shishi * handle,
@@ -712,16 +735,16 @@ extern Shishi_tkt *shishi_tkt2 (Shishi * handle,
 extern void shishi_tkt_pretty_print (Shishi_tkt * tkt, FILE * fh);
 extern int shishi_tkt_realm (Shishi_tkt * tkt, char **realm,
 			     size_t * realmlen);
-extern int shishi_tkt_cnamerealm (Shishi_tkt * tkt, char *cnamerealm,
-				  size_t * cnamerealmlen);
-extern int shishi_tkt_cnamerealm_p (Shishi_tkt * tkt, const char *client);
 extern int shishi_tkt_client (Shishi_tkt * tkt,
-			      char *client, size_t * clientlen);
+			      char **client, size_t * clientlen);
 extern int shishi_tkt_client_p (Shishi_tkt * tkt, const char *client);
+extern int shishi_tkt_clientrealm (Shishi_tkt * tkt,
+				   char **client, size_t *clientlen);
+extern int shishi_tkt_clientrealm_p (Shishi_tkt * tkt, const char *client);
 extern int shishi_tkt_clientrealm_set (Shishi_tkt * tkt,
-				       char *realm, char *client);
+				       const char *realm, const char *client);
 extern int shishi_tkt_serverrealm_set (Shishi_tkt * tkt,
-				       char *realm, char *server);
+				       const char *realm, const char *server);
 extern int shishi_tkt_build (Shishi_tkt * tkt, Shishi_key * key);
 extern int shishi_tkt_lastreq (Shishi_tkt * tkt,
 			       char **lrtime, size_t * lrtimelen,
@@ -747,9 +770,6 @@ extern int shishi_tkt_keytype_p (Shishi_tkt * tkt, int32_t etype);
 extern int shishi_tkt_server (Shishi_tkt * tkt,
 			      char **server, size_t * serverlen);
 extern int shishi_tkt_server_p (Shishi_tkt * tkt, const char *server);
-extern int shishi_tkt_server_realm (Shishi_tkt * tkt,
-				    char *serverrealm,
-				    size_t * serverrealmlen);
 extern int shishi_tkt_valid_at_time_p (Shishi_tkt * tkt, time_t now);
 extern int shishi_tkt_valid_now_p (Shishi_tkt * tkt);
 extern int shishi_tkt_expired_p (Shishi_tkt * tkt);
@@ -885,13 +905,12 @@ extern int shishi_authenticator_seqnumber_remove (Shishi * handle,
 extern int shishi_authenticator_seqnumber_set (Shishi * handle,
 					       Shishi_asn1 authenticator,
 					       uint32_t seqnumber);
-extern int shishi_authenticator_cname_get (Shishi * handle,
-					   Shishi_asn1 authenticator,
-					   char *cname, size_t * cnamelen);
-extern int shishi_authenticator_cnamerealm_get (Shishi * handle,
-						Shishi_asn1 authenticator,
-						char *cnamerealm,
-						size_t * cnamerealmlen);
+extern int shishi_authenticator_client (Shishi * handle,
+					Shishi_asn1 authenticator,
+					char **client, size_t *clientlen);
+extern int shishi_authenticator_clientrealm (Shishi * handle,
+					     Shishi_asn1 authenticator,
+					     char **client, size_t *clientlen);
 extern int shishi_authenticator_remove_cksum (Shishi * handle,
 					      Shishi_asn1 authenticator);
 extern int shishi_authenticator_cksum (Shishi * handle,
@@ -950,7 +969,7 @@ extern int
 shishi_authenticator_authorizationdata (Shishi * handle,
 					Shishi_asn1 authenticator,
 					int32_t * adtype,
-					char *addata, size_t * addatalen,
+					char **addata, size_t * addatalen,
 					size_t nth);
 extern int shishi_authenticator_read (Shishi * handle, FILE * fh,
 				      Shishi_asn1 * authenticator);
@@ -1048,35 +1067,27 @@ extern int shishi_kdcreq_read (Shishi * handle, FILE * fh,
 			       Shishi_asn1 * kdcreq);
 extern int shishi_kdcreq_from_file (Shishi * handle, Shishi_asn1 * kdcreq,
 				    int filetype, const char *filename);
-extern int shishi_asreq_cnamerealm_get (Shishi * handle, Shishi_asn1 kdcreq,
-					char *cnamerealm,
-					size_t * cnamerealmlen);
+extern int shishi_asreq_clientrealm (Shishi * handle,
+				     Shishi_asn1 asreq,
+				     char **client, size_t * clientlen);
 extern int shishi_kdcreq_nonce (Shishi * handle, Shishi_asn1 kdcreq,
 				uint32_t * nonce);
 extern int shishi_kdcreq_nonce_set (Shishi * handle,
 				    Shishi_asn1 kdcreq, uint32_t nonce);
 extern int shishi_kdcreq_client (Shishi * handle, Shishi_asn1 kdcreq,
 				 char **client, size_t * clientlen);
-extern int shishi_kdcreq_cname_get (Shishi * handle,
-				    Shishi_asn1 kdcreq,
-				    char *cname, size_t * cnamelen);
 extern int shishi_kdcreq_set_cname (Shishi * handle, Shishi_asn1 kdcreq,
 				    Shishi_name_type name_type,
 				    const char *principal);
 extern int shishi_kdcreq_server (Shishi * handle, Shishi_asn1 kdcreq,
 				 char **server, size_t * serverlen);
-extern int shishi_kdcreq_sname_get (Shishi * handle, Shishi_asn1 kdcreq,
-				    char *sname, size_t * snamelen);
-extern int shishi_kdcreq_snamerealm_get (Shishi * handle, Shishi_asn1 kdcreq,
-					 char *snamerealm,
-					 size_t * snamerealmlen);
 extern int shishi_kdcreq_set_sname (Shishi * handle, Shishi_asn1 kdcreq,
 				    Shishi_name_type name_type,
 				    const char *sname[]);
 extern int shishi_kdcreq_realm (Shishi * handle, Shishi_asn1 kdcreq,
 				char **realm, size_t * realmlen);
 extern int shishi_kdcreq_realm_get (Shishi * handle, Shishi_asn1 kdcreq,
-				    char *realm, size_t * realmlen);
+				    char **realm, size_t * realmlen);
 extern int shishi_kdcreq_set_realm (Shishi * handle, Shishi_asn1 kdcreq,
 				    const char *realm);
 extern int shishi_kdcreq_set_server (Shishi * handle, Shishi_asn1 req,
@@ -1277,9 +1288,9 @@ extern int shishi_krberror_remove_crealm (Shishi * handle,
 extern int shishi_krberror_set_crealm (Shishi * handle,
 				       Shishi_asn1 krberror,
 				       const char *crealm);
-extern int shishi_krberror_cname (Shishi * handle,
-				  Shishi_asn1 krberror,
-				  char *out, size_t * outlen);
+extern int shishi_krberror_client (Shishi * handle,
+				   Shishi_asn1 krberror,
+				   char **cname, size_t *cnamelen);
 extern int shishi_krberror_set_cname (Shishi * handle,
 				      Shishi_asn1 krberror,
 				      Shishi_name_type name_type,
@@ -1295,9 +1306,9 @@ extern int shishi_krberror_realm (Shishi * handle,
 extern int shishi_krberror_set_realm (Shishi * handle,
 				      Shishi_asn1 krberror,
 				      const char *realm);
-extern int shishi_krberror_sname (Shishi * handle,
-				  Shishi_asn1 krberror,
-				  char *out, size_t * outlen);
+extern int shishi_krberror_server (Shishi * handle,
+				   Shishi_asn1 krberror,
+				   char **server, size_t *serverlen);
 extern int shishi_krberror_remove_sname (Shishi * handle,
 					 Shishi_asn1 krberror);
 extern int shishi_krberror_set_sname (Shishi * handle,
@@ -1539,21 +1550,18 @@ extern int
 shishi_prompt_password (Shishi * handle, char **s, const char *format, ...);
 
 /* asn1.c */
-extern int shishi_a2d_field (Shishi * handle,
-			     Shishi_asn1 node,
-			     const char *field, char *der, size_t * len);
-extern int shishi_a2d (Shishi * handle, Shishi_asn1 node,
-		       char *der, size_t * len);
-extern int shishi_a2d_new_field (Shishi * handle, Shishi_asn1 node,
-				 const char *field, char **der, size_t * len);
-extern int shishi_new_a2d (Shishi * handle, Shishi_asn1 node,
-			   char **der, size_t * len);
-extern void shishi_asn1_done (Shishi * handle, Shishi_asn1 node);
+extern int shishi_asn1_number_of_elements (Shishi * handle,
+					   Shishi_asn1 node,
+					   const char *field, size_t * n);
+extern int shishi_asn1_empty_p (Shishi * handle, Shishi_asn1 node,
+				const char *field);
+
 extern int shishi_asn1_read (Shishi * handle, Shishi_asn1 node,
-			     const char *field, char *data, size_t * datalen);
-extern int shishi_asn1_read2 (Shishi * handle, Shishi_asn1 node,
-			      const char *field,
-			      char **data, size_t * datalen);
+			     const char *field,
+			     char **data, size_t * datalen);
+extern int shishi_asn1_read_inline (Shishi * handle, Shishi_asn1 node,
+				    const char *field,
+				    char *data, size_t * datalen);
 extern int shishi_asn1_read_integer (Shishi * handle, Shishi_asn1 node,
 				     const char *field, int *i);
 extern int shishi_asn1_read_int32 (Shishi * handle, Shishi_asn1 node,
@@ -1564,12 +1572,8 @@ extern int shishi_asn1_read_bitstring (Shishi * handle, Shishi_asn1 node,
 				       const char *field, uint32_t * flags);
 extern int shishi_asn1_read_optional (Shishi * handle,
 				      Shishi_asn1 node, const char *field,
-				      char *data, size_t * datalen);
-extern int shishi_asn1_read2_optional (Shishi * handle,
-				       Shishi_asn1 node, const char *field,
-				       char **data, size_t * datalen);
-extern int shishi_asn1_empty_p (Shishi * handle, Shishi_asn1 node,
-				const char *field);
+				      char **data, size_t * datalen);
+
 extern int shishi_asn1_write (Shishi * handle, Shishi_asn1 node,
 			      const char *field,
 			      const char *data, size_t datalen);
@@ -1581,9 +1585,9 @@ extern int shishi_asn1_write_uint32 (Shishi * handle, Shishi_asn1 node,
 				     const char *field, uint32_t n);
 extern int shishi_asn1_write_bitstring (Shishi * handle, Shishi_asn1 node,
 					const char *field, uint32_t flags);
-extern int shishi_asn1_number_of_elements (Shishi * handle,
-					   Shishi_asn1 node,
-					   const char *field, size_t * n);
+
+extern void shishi_asn1_done (Shishi * handle, Shishi_asn1 node);
+
 extern Shishi_asn1 shishi_asn1_asreq (Shishi * handle);
 extern Shishi_asn1 shishi_asn1_asrep (Shishi * handle);
 extern Shishi_asn1 shishi_asn1_tgsreq (Shishi * handle);
@@ -1601,6 +1605,11 @@ extern Shishi_asn1 shishi_asn1_krbsafe (Shishi * handle);
 extern Shishi_asn1 shishi_asn1_priv (Shishi * handle);
 extern Shishi_asn1 shishi_asn1_encprivpart (Shishi * handle);
 
+extern int shishi_asn1_to_der (Shishi * handle, Shishi_asn1 node,
+			       char **der, size_t * len);
+extern int shishi_asn1_to_der_field (Shishi * handle, Shishi_asn1 node,
+				     const char *field, char **der, size_t * len);
+
 extern Shishi_msgtype shishi_asn1_msgtype (Shishi * handle, Shishi_asn1 node);
 extern Shishi_msgtype shishi_der_msgtype (Shishi * handle,
 					  const char *der, size_t derlen);
@@ -1859,9 +1868,7 @@ extern int shishi_encapreppart_from_file (Shishi * handle,
 					  int filetype, const char *filename);
 extern int shishi_encapreppart_get_key (Shishi * handle,
 					Shishi_asn1 encapreppart,
-					int32_t * keytype,
-					char *keyvalue,
-					size_t * keyvalue_len);
+					Shishi_key ** key);
 extern int shishi_encapreppart_seqnumber_get (Shishi * handle,
 					      Shishi_asn1 encapreppart,
 					      uint32_t * seqnumber);
@@ -1936,6 +1943,7 @@ extern int shishi_aprep_enc_part_add (Shishi * handle, Shishi_asn1 aprep,
 				      Shishi_asn1 encticketpart,
 				      Shishi_asn1 encapreppart);
 extern int shishi_aprep_enc_part_make (Shishi * handle, Shishi_asn1 aprep,
+				       Shishi_asn1 encapreppart,
 				       Shishi_asn1 authenticator,
 				       Shishi_asn1 encticketpart);
 extern int shishi_aprep_get_enc_part_etype (Shishi * handle,
@@ -1971,17 +1979,13 @@ extern int shishi_encticketpart_crealm_set (Shishi * handle,
 extern int shishi_encticketpart_client (Shishi * handle,
 					Shishi_asn1 encticketpart,
 					char **client, size_t * clientlen);
-extern int shishi_encticketpart_cname_get (Shishi * handle,
-					   Shishi_asn1 encticketpart,
-					   char *cname, size_t * cnamelen);
+extern int shishi_encticketpart_clientrealm (Shishi * handle,
+					     Shishi_asn1 encticketpart,
+					     char **client, size_t *clientlen);
 extern int shishi_encticketpart_cname_set (Shishi * handle,
 					   Shishi_asn1 encticketpart,
 					   Shishi_name_type name_type,
 					   const char *principal);
-extern int shishi_encticketpart_cnamerealm_get (Shishi * handle,
-						Shishi_asn1 encticketpart,
-						char *cnamerealm,
-						size_t * cnamerealmlen);
 extern int shishi_encticketpart_print (Shishi * handle, FILE * fh,
 				       Shishi_asn1 encticketpart);
 extern int shishi_encticketpart_flags_set (Shishi * handle,
@@ -2107,4 +2111,8 @@ extern const char *shishi_x509key_default_file (Shishi * handle);
 /* utils.c */
 extern time_t shishi_get_date (const char *p, const time_t * now);
 
+/* resolv.c */
+Shishi_dns shishi_resolv (const char *zone, uint16_t querytype);
+void shishi_resolv_free (Shishi_dns rrs);
+
 #endif
