@@ -1,5 +1,5 @@
 /* ticket.c	low-level ASN.1 Ticket handling
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -44,14 +44,14 @@ shishi_ticket (Shishi * handle)
     return NULL;
 
   rc = shishi_asn1_write (handle, node, "tkt-vno",
-			   SHISHI_TICKET_DEFAULT_TKTVNO,
-			   SHISHI_TICKET_DEFAULT_TKTVNO_LEN);
+			  SHISHI_TICKET_DEFAULT_TKTVNO,
+			  SHISHI_TICKET_DEFAULT_TKTVNO_LEN);
   if (rc != SHISHI_OK)
     goto error;
 
   return node;
 
- error:
+error:
   shishi_asn1_done (handle, node);
   return NULL;
 }
@@ -71,7 +71,7 @@ int
 shishi_ticket_realm_get (Shishi * handle,
 			 Shishi_asn1 ticket, char **realm, size_t * realmlen)
 {
-  return shishi_asn1_read2 (handle, ticket, "realm", realm, realmlen);
+  return shishi_asn1_read (handle, ticket, "realm", realm, realmlen);
 }
 
 /**
@@ -120,14 +120,6 @@ shishi_ticket_server (Shishi * handle, Shishi_asn1 ticket,
   return shishi_principal_name (handle, ticket, "sname", server, serverlen);
 }
 
-int
-shishi_ticket_sname_get (Shishi * handle,
-			 Shishi_asn1 ticket, char *server, size_t * serverlen)
-{
-  return shishi_principal_name_get (handle, ticket, "sname",
-				    server, serverlen);
-}
-
 /**
  * shishi_ticket_sname_set:
  * @handle: shishi handle as allocated by shishi_init().
@@ -210,19 +202,10 @@ shishi_ticket_set_server (Shishi * handle,
   return SHISHI_OK;
 }
 
-int
-shishi_ticket_snamerealm_get (Shishi * handle,
-			      Shishi_asn1 ticket,
-			      char *serverrealm, size_t * serverrealmlen)
-{
-  return shishi_principal_name_realm_get (handle, ticket, "sname",
-					  ticket, "realm",
-					  serverrealm, serverrealmlen);
-}
-
 int
 shishi_ticket_srealmserver_set (Shishi * handle,
-				Shishi_asn1 ticket, char *realm, char *server)
+				Shishi_asn1 ticket,
+				const char *realm, const char *server)
 {
   int res;
 
@@ -278,8 +261,8 @@ shishi_ticket_decrypt (Shishi * handle,
   if (etype != shishi_key_type (key))
     return SHISHI_TICKET_BAD_KEYTYPE;
 
-  res = shishi_asn1_read2 (handle, ticket, "enc-part.cipher",
-			   &cipher, &cipherlen);
+  res = shishi_asn1_read (handle, ticket, "enc-part.cipher",
+			  &cipher, &cipherlen);
   if (res != SHISHI_OK)
     return res;
 
@@ -381,7 +364,7 @@ shishi_ticket_add_enc_part (Shishi * handle,
   char *der;
   size_t derlen;
 
-  res = shishi_new_a2d (handle, encticketpart, &der, &derlen);
+  res = shishi_asn1_to_der (handle, encticketpart, &der, &derlen);
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle, "Could not DER encode encticketpart: %s\n",
