@@ -1,4 +1,4 @@
-/* tkt.c	ticket handling
+/* tkt.c --- Ticket handling.
  * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
@@ -317,7 +317,8 @@ shishi_tkt_key_set (Shishi_tkt * tkt, Shishi_key * key)
 }
 
 int
-shishi_tkt_clientrealm_set (Shishi_tkt * tkt, char *realm, char *client)
+shishi_tkt_clientrealm_set (Shishi_tkt * tkt,
+			    const char *realm, const char *client)
 {
   int res;
 
@@ -336,7 +337,8 @@ shishi_tkt_clientrealm_set (Shishi_tkt * tkt, char *realm, char *client)
 }
 
 int
-shishi_tkt_serverrealm_set (Shishi_tkt * tkt, char *realm, char *server)
+shishi_tkt_serverrealm_set (Shishi_tkt * tkt,
+			    const char *realm, const char *server)
 {
   int res;
 
@@ -356,17 +358,24 @@ shishi_tkt_serverrealm_set (Shishi_tkt * tkt, char *realm, char *server)
 /**
  * shishi_tkt_client:
  * @tkt: input variable with ticket info.
- * @client: output buffer that holds client name of ticket.
- * @clientlen: on input, maximum size of output buffer,
- *             on output, actual size of output buffer.
+ * @client: pointer to newly allocated zero terminated string containing
+ *   principal name.  May be %NULL (to only populate @clientlen).
+ * @clientlen: pointer to length of @client on output, excluding terminating
+ *   zero.  May be %NULL (to only populate @client).
  *
- * Return value: Returns client principal of ticket.
+ * Represent client principal name in Ticket KDC-REP as
+ * zero-terminated string.  The string is allocate by this function,
+ * and it is the responsibility of the caller to deallocate it.  Note
+ * that the output length @clientlen does not include the terminating
+ * zero.
+ *
+ * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_tkt_client (Shishi_tkt * tkt, char *client, size_t * clientlen)
+shishi_tkt_client (Shishi_tkt * tkt, char **client, size_t * clientlen)
 {
-  return shishi_principal_name_get (tkt->handle, tkt->kdcrep,
-				    "cname", client, clientlen);
+  return shishi_principal_name (tkt->handle, tkt->kdcrep,
+				"cname", client, clientlen);
 }
 
 /**
@@ -385,40 +394,43 @@ shishi_tkt_client_p (Shishi_tkt * tkt, const char *client)
   size_t buflen;
   int res;
 
-  buflen = strlen (client) + 1;
-  buf = xmalloc (buflen);
-
-  res = shishi_tkt_client (tkt, buf, &buflen);
+  res = shishi_tkt_client (tkt, &buf, &buflen);
   if (res != SHISHI_OK)
-    {
-      free (buf);
-      return 0;
-    }
-  buf[buflen] = '\0';
+    return 0;
 
-  if (strcmp (client, buf) != 0)
-    {
-      free (buf);
-      return 0;
-    }
+  res = strcmp (client, buf) == 0;
 
   free (buf);
 
-  return 1;
-}
-
-int
-shishi_tkt_cnamerealm (Shishi_tkt * tkt,
-		       char *cnamerealm, size_t * cnamerealmlen)
-{
-  return shishi_principal_name_realm_get (tkt->handle,
-					  tkt->kdcrep, "cname",
-					  tkt->kdcrep, "crealm",
-					  cnamerealm, cnamerealmlen);
+  return res;
 }
 
 /**
- * shishi_tkt_cnamerealm_p:
+ * shishi_tkt_clientrealm:
+ * @tkt: input variable with ticket info.
+ * @client: pointer to newly allocated zero terminated string containing
+ *   principal name and realm.  May be %NULL (to only populate @clientlen).
+ * @clientlen: pointer to length of @client on output, excluding terminating
+ *   zero.  May be %NULL (to only populate @client).
+ *
+ * Convert cname and realm fields from AS-REQ to printable principal
+ * name format.  The string is allocate by this function, and it is
+ * the responsibility of the caller to deallocate it.  Note that the
+ * output length @clientlen does not include the terminating zero.
+ *
+ * Return value: Returns SHISHI_OK iff successful.
+ **/
+int
+shishi_tkt_clientrealm (Shishi_tkt * tkt, char **client, size_t * clientlen)
+{
+  return shishi_principal_name_realm (tkt->handle,
+				      tkt->kdcrep, "cname",
+				      tkt->kdcrep, "crealm",
+				      client, clientlen);
+}
+
+/**
+ * shishi_tkt_clientrealm_p:
  * @tkt: input variable with ticket info.
  * @client: principal name (client name and realm) of ticket.
  *
@@ -427,32 +439,21 @@ shishi_tkt_cnamerealm (Shishi_tkt * tkt,
  * Return value: Returns non-0 iff ticket is for specified client principal.
  **/
 int
-shishi_tkt_cnamerealm_p (Shishi_tkt * tkt, const char *client)
+shishi_tkt_clientrealm_p (Shishi_tkt * tkt, const char *client)
 {
   char *buf;
   size_t buflen;
   int res;
 
-  buflen = strlen (client) + 1;
-  buf = xmalloc (buflen);
-
-  res = shishi_tkt_cnamerealm (tkt, buf, &buflen);
+  res = shishi_tkt_clientrealm (tkt, &buf, &buflen);
   if (res != SHISHI_OK)
-    {
-      free (buf);
-      return 0;
-    }
-  buf[buflen] = '\0';
+    return 0;
 
-  if (strcmp (client, buf) != 0)
-    {
-      free (buf);
-      return 0;
-    }
+  res = strcmp (client, buf) == 0;
 
   free (buf);
 
-  return 1;
+  return res;
 }
 
 /**
@@ -518,14 +519,6 @@ shishi_tkt_server_p (Shishi_tkt * tkt, const char *server)
   return res;
 }
 
-int
-shishi_tkt_server_realm (Shishi_tkt * tkt,
-			 char *serverrealm, size_t * serverrealmlen)
-{
-  return shishi_ticket_snamerealm_get (tkt->handle, tkt->ticket,
-				       serverrealm, serverrealmlen);
-}
-
 /**
  * shishi_tkt_flags:
  * @tkt: input variable with ticket info.
@@ -536,7 +529,7 @@ shishi_tkt_server_realm (Shishi_tkt * tkt,
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_tkt_flags (Shishi_tkt * tkt, uint32_t *flags)
+shishi_tkt_flags (Shishi_tkt * tkt, uint32_t * flags)
 {
   return shishi_asn1_read_bitstring (tkt->handle, tkt->enckdcreppart,
 				     "flags", flags);
@@ -1033,8 +1026,7 @@ shishi_tkt_keytype_p (Shishi_tkt * tkt, int32_t etype)
 
 int
 shishi_tkt_lastreq (Shishi_tkt * tkt,
-		    char **lrtime, size_t * lrtimelen,
-		    int32_t lrtype)
+		    char **lrtime, size_t * lrtimelen, int32_t lrtype)
 {
   char *format;
   int32_t tmplrtype;
@@ -1058,8 +1050,8 @@ shishi_tkt_lastreq (Shishi_tkt * tkt,
       if (lrtype == tmplrtype)
 	{
 	  asprintf (&format, "last-req.?%d.lr-value", i);
-	  res = shishi_asn1_read2 (tkt->handle, tkt->enckdcreppart,
-				   format, lrtime, lrtimelen);
+	  res = shishi_asn1_read (tkt->handle, tkt->enckdcreppart,
+				  format, lrtime, lrtimelen);
 	  free (format);
 	  if (res != SHISHI_OK)
 	    return res;
@@ -1088,14 +1080,14 @@ shishi_tkt_lastreqc (Shishi_tkt * tkt, Shishi_lrtype lrtype)
 {
   char *lrtime;
   size_t lrtimelen;
-  time_t t = (time_t) -1;
+  time_t t = (time_t) - 1;
   int res;
 
   res = shishi_tkt_lastreq (tkt, &lrtime, &lrtimelen, lrtype);
   if (res != SHISHI_OK)
     return t;
 
-  if (lrtimelen == GENERALIZEDTIME_TIME_LEN)
+  if (lrtimelen == SHISHI_GENERALIZEDTIME_LENGTH)
     t = shishi_generalize_ctime (tkt->handle, lrtime);
 
   free (lrtime);
@@ -1106,8 +1098,8 @@ shishi_tkt_lastreqc (Shishi_tkt * tkt, Shishi_lrtype lrtype)
 int
 shishi_tkt_authtime (Shishi_tkt * tkt, char **authtime, size_t * authtimelen)
 {
-  return shishi_asn1_read2 (tkt->handle, tkt->enckdcreppart, "authtime",
-			    authtime, authtimelen);
+  return shishi_asn1_read (tkt->handle, tkt->enckdcreppart, "authtime",
+			   authtime, authtimelen);
 }
 
 /**
@@ -1125,14 +1117,14 @@ shishi_tkt_authctime (Shishi_tkt * tkt)
 {
   char *authtime;
   size_t authtimelen;
-  time_t t = (time_t) -1;
+  time_t t = (time_t) - 1;
   int res;
 
   res = shishi_tkt_authtime (tkt, &authtime, &authtimelen);
   if (res != SHISHI_OK)
     return t;
 
-  if (authtimelen == GENERALIZEDTIME_TIME_LEN + 1) /* XXX why +1 ? */
+  if (authtimelen == SHISHI_GENERALIZEDTIME_LENGTH + 1)	/* XXX why +1 ? */
     t = shishi_generalize_ctime (tkt->handle, authtime);
 
   free (authtime);
@@ -1142,11 +1134,10 @@ shishi_tkt_authctime (Shishi_tkt * tkt)
 
 int
 shishi_tkt_starttime (Shishi_tkt * tkt,
-		      char **starttime,
-		      size_t * starttimelen)
+		      char **starttime, size_t * starttimelen)
 {
-  return shishi_asn1_read2_optional (tkt->handle, tkt->enckdcreppart,
-				     "starttime", starttime, starttimelen);
+  return shishi_asn1_read_optional (tkt->handle, tkt->enckdcreppart,
+				    "starttime", starttime, starttimelen);
 }
 
 /**
@@ -1164,14 +1155,14 @@ shishi_tkt_startctime (Shishi_tkt * tkt)
 {
   char *starttime;
   size_t starttimelen;
-  time_t t = (time_t) -1;
+  time_t t = (time_t) - 1;
   int res;
 
   res = shishi_tkt_starttime (tkt, &starttime, &starttimelen);
   if (res != SHISHI_OK || starttimelen == 0)
     return t;
 
-  if (starttimelen == GENERALIZEDTIME_TIME_LEN + 1) /* XXX why +1 ? */
+  if (starttimelen == SHISHI_GENERALIZEDTIME_LENGTH + 1)	/* XXX why +1 ? */
     t = shishi_generalize_ctime (tkt->handle, starttime);
 
   free (starttime);
@@ -1182,8 +1173,8 @@ shishi_tkt_startctime (Shishi_tkt * tkt)
 int
 shishi_tkt_endtime (Shishi_tkt * tkt, char **endtime, size_t * endtimelen)
 {
-  return shishi_asn1_read2 (tkt->handle, tkt->enckdcreppart, "endtime",
-			    endtime, endtimelen);
+  return shishi_asn1_read (tkt->handle, tkt->enckdcreppart, "endtime",
+			   endtime, endtimelen);
 }
 
 /**
@@ -1200,14 +1191,14 @@ shishi_tkt_endctime (Shishi_tkt * tkt)
 {
   char *endtime;
   size_t endtimelen;
-  time_t t = (time_t) -1;
+  time_t t = (time_t) - 1;
   int res;
 
   res = shishi_tkt_endtime (tkt, &endtime, &endtimelen);
   if (res != SHISHI_OK)
     return t;
 
-  if (endtimelen == GENERALIZEDTIME_TIME_LEN + 1) /* XXX why +1 ? */
+  if (endtimelen == SHISHI_GENERALIZEDTIME_LENGTH + 1)	/* XXX why +1 ? */
     t = shishi_generalize_ctime (tkt->handle, endtime);
 
   free (endtime);
@@ -1217,11 +1208,10 @@ shishi_tkt_endctime (Shishi_tkt * tkt)
 
 int
 shishi_tkt_renew_till (Shishi_tkt * tkt,
-		       char **renewtill,
-		       size_t * renewtilllen)
+		       char **renewtill, size_t * renewtilllen)
 {
-  return shishi_asn1_read2_optional (tkt->handle, tkt->enckdcreppart,
-				     "renew-till", renewtill, renewtilllen);
+  return shishi_asn1_read_optional (tkt->handle, tkt->enckdcreppart,
+				    "renew-till", renewtill, renewtilllen);
 }
 
 /**
@@ -1238,14 +1228,14 @@ shishi_tkt_renew_tillc (Shishi_tkt * tkt)
 {
   char *renewtill;
   size_t renewtilllen;
-  time_t t = (time_t) -1;
+  time_t t = (time_t) - 1;
   int res;
 
   res = shishi_tkt_renew_till (tkt, &renewtill, &renewtilllen);
   if (res != SHISHI_OK || renewtilllen == 0)
     return t;
 
-  if (renewtilllen == GENERALIZEDTIME_TIME_LEN + 1) /* XXX why +1 ? */
+  if (renewtilllen == SHISHI_GENERALIZEDTIME_LENGTH + 1)	/* XXX why +1 ? */
     t = shishi_generalize_ctime (tkt->handle, renewtill);
 
   free (renewtill);
@@ -1355,8 +1345,7 @@ shishi_tkt_lastreq_pretty_print (Shishi_tkt * tkt, FILE * fh)
 void
 shishi_tkt_pretty_print (Shishi_tkt * tkt, FILE * fh)
 {
-  char buf[BUFSIZ];
-  char *buf2;
+  char *buf;
   char *p;
   size_t buflen;
   int keytype, etype;
@@ -1365,11 +1354,9 @@ shishi_tkt_pretty_print (Shishi_tkt * tkt, FILE * fh)
   time_t t;
   time_t now = time (NULL);
 
-  buflen = sizeof (buf);
-  buf[0] = '\0';
-  res = shishi_tkt_cnamerealm (tkt, buf, &buflen);
-  buf[buflen] = '\0';
+  res = shishi_tkt_clientrealm (tkt, &buf, &buflen);
   fprintf (fh, "%s:\n", buf);
+  free (buf);
 
   t = shishi_tkt_authctime (tkt);
   fprintf (fh, _("Authtime:\t%s"), ctime (&t));
@@ -1400,10 +1387,16 @@ shishi_tkt_pretty_print (Shishi_tkt * tkt, FILE * fh)
   if (t != (time_t) - 1)
     fprintf (fh, _("Renewable till:\t%s"), ctime (&t));
 
-  res = shishi_tkt_server (tkt, &buf2, NULL);
-  res = shishi_ticket_get_enc_part_etype (tkt->handle, tkt->ticket, &keytype);
-  fprintf (fh, _("Server:\t\t%s key %s (%d)\n"), buf2,
-	   shishi_cipher_name (keytype), keytype);
+  res = shishi_tkt_server (tkt, &buf, NULL);
+  if (res == SHISHI_OK)
+    {
+      res = shishi_ticket_get_enc_part_etype (tkt->handle, tkt->ticket,
+					      &keytype);
+      if (res == SHISHI_OK)
+	fprintf (fh, _("Server:\t\t%s key %s (%d)\n"), buf,
+		 shishi_cipher_name (keytype), keytype);
+      free (buf);
+    }
 
   res = shishi_tkt_keytype (tkt, &keytype);
   res = shishi_kdcrep_get_enc_part_etype (tkt->handle, tkt->kdcrep, &etype);
