@@ -135,7 +135,7 @@ xgettimeofday (struct timeval *tv, struct timezone *tz)
 }
 
 time_t
-shishi_get_date (const char *p, const time_t *now)
+shishi_get_date (const char *p, const time_t * now)
 {
   struct timespec nowspec = { 0, 0 };
   struct timespec thenspec;
@@ -147,9 +147,22 @@ shishi_get_date (const char *p, const time_t *now)
 
   if (!get_date (&thenspec, p, &nowspec))
     {
-      thenspec.tv_sec = (time_t) -1;
+      thenspec.tv_sec = (time_t) - 1;
       thenspec.tv_nsec = 0;
     }
 
   return thenspec.tv_sec;
 }
+
+/* If non-NULL, call this function when memory is exhausted. */
+void (*shishi_alloc_fail_function) (void) = 0;
+
+void
+xalloc_die (void)
+{
+  if (shishi_alloc_fail_function)
+    (*shishi_alloc_fail_function) ();
+  fflush (stdout);
+  fprintf (stderr, _("%s: Memory allocation failed\n"), PACKAGE);
+  abort ();
+}
